# Overview

A library for communication with Skydance lighting WiFi relay.

[![Build Status](https://img.shields.io/travis/tomasbedrich/skydance.svg)](https://travis-ci.org/tomasbedrich/skydance)
[![Coverage Status](https://img.shields.io/coveralls/tomasbedrich/skydance.svg)](https://coveralls.io/r/tomasbedrich/skydance)
[![Scrutinizer Code Quality](https://img.shields.io/scrutinizer/g/tomasbedrich/skydance.svg)](https://scrutinizer-ci.com/g/tomasbedrich/skydance)
[![PyPI Version](https://img.shields.io/pypi/v/skydance.svg)](https://pypi.org/project/skydance)
[![PyPI License](https://img.shields.io/pypi/l/skydance.svg)](https://pypi.org/project/skydance)

# Setup

## Requirements

* Python 3.8+

## Installation

Install it directly into an activated virtual environment:

```text
$ pip install skydance
```

or add it to your [Poetry](https://poetry.eustace.io/) project:

```text
$ poetry add skydance
```

# Usage

After installation, the package can imported:

```text
$ python
>>> import skydance
>>> skydance.__version__
```
